#============================================================================
# copy_filtered_dir.mk

COPY_FILTERED_DIR_MK =

# this snippet defines a sequence of shell commands which will
# recursively copy files within a directory to a destination. it first
# checks for the directory in the current directory; if it is not
# found there, it assumes it is in $srcdir.  This is useful for
# things which are created by the maintainer and distributed.
# They will thus be in builddir for the maintainer and srcdir for the
# end user.
#
# To use this, first set these shell variables
#
#  source_dir - the directory holding the original files
#  dest_dir   - the directory where the files are to be installed
#  filter     - a command or file glob which will result in a list of files
#
# then interpolate $(copy_filtered_dir).  filter is used inside of an eval:
#
#   eval "files=$filter"
#
# so take care with quoting.  The "real" source directory is provided
# in the $rsrcdir variable.

# Here's a filter which copies all files not in CVS directories and
# without a backup extension of ~:
#
#  filter='`find $$rsrcdir \( -name CVS -o -name \*~ \) -prune  -o -type f -print`'
#
# A simpler one which just grabs all files with extension .mk:
#
#  filter='$$rsrcdir/*.mk'
#
# Note the doubling of the $ character to get it past make.

# Heres a full example
#
#install-data-local:
#	source_dir=snippets; \
#	dest_dir=$(pkgdatadir)/snippets; \
#	filter='`find $$rsrcdir \( -name CVS -o -name \*~ \) -prune  -o -type f -print`' \
#	$(copy_filtered_dir)

copy_filtered_dir =	\
	if test -d "$$source_dir"; then d=; else d="$(srcdir)/"; fi; \
	rsrcdir=$$d$$source_dir ; \
	eval "files=$$filter" ;\
	for p in $$files; do \
	  f="`echo $$p | sed -e \"s|^$$rsrcdir/||\"`"; \
	  ld=`dirname $(DESTDIR)$$dest_dir/$$f` ;\
	  if [ ! -d $$ld ]; then \
	    echo "$(mkinstalldirs) $$ld" ; \
	    $(mkinstalldirs) $$ld ; \
	  fi; \
	  echo " cp -R $$p $(DESTDIR)$$dest_dir/$$f"; \
	  cp -R $$p $(DESTDIR)$$dest_dir/$$f; \
	done
